@@ -35,7 +35,6 @@
 #include <eel/eel-gdk-extensions.h>
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-graphic-effects.h>
-#include <eel/eel-gtk-macros.h>
 #include <eel/eel-string.h>
 #include <eel/eel-accessibility.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
@@ -183,13 +182,6 @@ static void     draw_pixbuf                          (GdkPixbuf
 static PangoLayout *get_label_layout                 (PangoLayout                  **layout,
 						      NautilusIconCanvasItem        *item,
 						      const char                    *text);
-static void     draw_label_layout                    (NautilusIconCanvasItem        *item,
-						      cairo_t                       *cr,
-						      PangoLayout                   *layout,
-						      gboolean                       highlight,
-						      GdkRGBA                       *label_color,
-						      int                            x,
-						      int                            y);
 static gboolean hit_test_stretch_handle              (NautilusIconCanvasItem        *item,
 						      EelIRect                       canvas_rect,
 						      GtkCornerType *corner);
@@ -306,14 +298,16 @@ nautilus_icon_canvas_item_set_property (GObject        *object,
 {
 	NautilusIconCanvasItem *item;
 	NautilusIconCanvasItemDetails *details;
+	AtkObject *accessible;
 
 	item = NAUTILUS_ICON_CANVAS_ITEM (object);
+	accessible = atk_gobject_accessible_for_object (G_OBJECT (item));
 	details = item->details;
 
 	switch (property_id) {
 
 	case PROP_EDITABLE_TEXT:
-		if (eel_strcmp (details->editable_text,
+		if (g_strcmp0 (details->editable_text,
 				g_value_get_string (value)) == 0) {
 			return;
 		}
@@ -321,11 +315,8 @@ nautilus_icon_canvas_item_set_property (GObject        *object,
 		g_free (details->editable_text);
 		details->editable_text = g_strdup (g_value_get_string (value));
 		if (details->text_util) {
-			AtkObject *accessible;
-
 			gail_text_util_text_setup (details->text_util,
 						   details->editable_text);
-			accessible = atk_gobject_accessible_for_object (G_OBJECT (item));
 			g_object_notify (G_OBJECT(accessible), "accessible-name");
 		}
 		
@@ -337,8 +328,8 @@ nautilus_icon_canvas_item_set_property (GObject        *object,
 		break;
 
 	case PROP_ADDITIONAL_TEXT:
-		if (eel_strcmp (details->additional_text,
-				g_value_get_string (value)) == 0) {
+		if (g_strcmp0 (details->additional_text,
+			       g_value_get_string (value)) == 0) {
 			return;
 		}
 
@@ -358,6 +349,10 @@ nautilus_icon_canvas_item_set_property (GObject        *object,
 		}
 		details->is_highlighted_for_selection = g_value_get_boolean (value);
 		nautilus_icon_canvas_item_invalidate_label_size (item);
+
+		atk_object_notify_state_change (accessible, ATK_STATE_SELECTED,
+						details->is_highlighted_for_selection);
+
 		break;
          
         case PROP_HIGHLIGHTED_AS_KEYBOARD_FOCUS:
@@ -367,8 +362,7 @@ nautilus_icon_canvas_item_set_property (GObject        *object,
 		details->is_highlighted_as_keyboard_focus = g_value_get_boolean (value);
 
 		if (details->is_highlighted_as_keyboard_focus) {
-			AtkObject *atk_object = atk_gobject_accessible_for_object (object);
-			atk_focus_tracker_notify (atk_object);
+			atk_focus_tracker_notify (accessible);
 		}
 		break;
 		
@@ -448,11 +442,16 @@ nautilus_icon_canvas_item_get_drag_surface (NautilusIconCanvasItem *item)
 	EelIRect icon_rect;
 	double item_x, item_y;
 	cairo_t *cr;
+	GtkStyleContext *context;
 	
 	g_return_val_if_fail (NAUTILUS_IS_ICON_CANVAS_ITEM (item), NULL);
 
 	canvas = EEL_CANVAS_ITEM (item)->canvas;
 	screen = gtk_widget_get_screen (GTK_WIDGET (canvas));
+	context = gtk_widget_get_style_context (GTK_WIDGET (canvas));
+
+	gtk_style_context_save (context);
+	gtk_style_context_add_class (context, "nautilus-canvas-item");
 
 	/* Assume we're updated so canvas item data is right */
 
@@ -474,12 +473,9 @@ nautilus_icon_canvas_item_get_drag_surface (NautilusIconCanvasItem *item)
                                                      width, height);
 
 	cr = cairo_create (surface);
-	gdk_cairo_set_source_pixbuf (cr, item->details->pixbuf,
-				     item_offset_x, item_offset_y);
-	cairo_rectangle (cr, item_offset_x, item_offset_y,
-			 gdk_pixbuf_get_width (item->details->pixbuf),
-			 gdk_pixbuf_get_height (item->details->pixbuf));
-	cairo_fill (cr);
+
+	gtk_render_icon (context, cr, item->details->pixbuf,
+			 item_offset_x, item_offset_y);
 
 	icon_rect.x0 = item_offset_x;
 	icon_rect.y0 = item_offset_y;
@@ -491,6 +487,8 @@ nautilus_icon_canvas_item_get_drag_surface (NautilusIconCanvasItem *item)
 	draw_label_text (item, cr, icon_rect);
 	cairo_destroy (cr);
 
+	gtk_style_context_restore (context);
+
 	return surface;
 }
 
@@ -752,68 +750,6 @@ in_single_click_mode (void)
 }
 
 
-/* Utility routine to create a rectangle with rounded corners.
- * This could possibly move to Eel as a general purpose routine. 
- */
-static void
-make_round_rect (cairo_t *cr,
-		 double x, 
-    		 double y, 
-		 double width, 
-		 double height,
-		 double radius)
-{
-	double cx, cy;
-	
-	width -= 2 * radius;
-	height -= 2 * radius;
-	
-	cairo_move_to (cr, x + radius, y);
-	
-	cairo_rel_line_to (cr, width, 0.0);
-	
-	cairo_get_current_point (cr, &cx, &cy);
-	cairo_arc (cr, cx, cy + radius, radius, 3.0 * G_PI_2, 0);
-
-	cairo_rel_line_to (cr, 0.0, height);
-
-	cairo_get_current_point (cr, &cx, &cy);
-	cairo_arc (cr, cx - radius, cy, radius, 0, G_PI_2);
-
-	cairo_rel_line_to (cr, - width, 0.0);
-	
-	cairo_get_current_point (cr, &cx, &cy);
-	cairo_arc (cr, cx, cy - radius, radius, G_PI_2, G_PI);
-
-	cairo_rel_line_to (cr, 0.0, -height);
-
-	cairo_get_current_point (cr, &cx, &cy);
-	cairo_arc (cr, cx + radius, cy, radius, G_PI, 3.0 * G_PI_2);
-
-	cairo_close_path (cr);
-}
-
-static void
-draw_frame (NautilusIconCanvasItem *item,
-	    cairo_t *cr,
-	    GdkRGBA *color,
-	    int x, 
-	    int y,
-	    int width,
-	    int height)
-{
-	cairo_save (cr);
-
-	/* Set the rounded rect clip region. Magic rounding value taken
-	 * from old code. 
-	 */
-	make_round_rect (cr, x, y, width, height, 5);
-	gdk_cairo_set_source_rgba (cr, color);
-	cairo_fill (cr);
-
-	cairo_restore (cr);
-}
-
 /* Keep these for a bit while we work on performance of draw_or_measure_label_text. */
 /*
   #define PERFORMANCE_TEST_DRAW_DISABLE
@@ -1084,23 +1020,24 @@ draw_label_text (NautilusIconCanvasItem *item,
                  cairo_t *cr,
 		 EelIRect icon_rect)
 {
-	EelCanvasItem *canvas_item;
 	NautilusIconCanvasItemDetails *details;
 	NautilusIconContainer *container;
 	PangoLayout *editable_layout;
 	PangoLayout *additional_layout;
-	GdkRGBA label_color;
+	GtkStyleContext *context;
+	GtkStateFlags state;
 	gboolean have_editable, have_additional;
 	gboolean needs_highlight, prelight_label, is_rtl_label_beside;
 	EelIRect text_rect;
 	int x;
 	int max_text_width;
+	gdouble frame_w, frame_h, frame_x, frame_y;
+	gboolean draw_frame = TRUE;
 
 #ifdef PERFORMANCE_TEST_DRAW_DISABLE
 	return;
 #endif
 
-	canvas_item = EEL_CANVAS_ITEM (item);
 	details = item->details;
 
 	measure_label_text (item);
@@ -1110,6 +1047,7 @@ draw_label_text (NautilusIconCanvasItem *item,
 	}
 
 	container = NAUTILUS_ICON_CONTAINER (EEL_CANVAS_ITEM (item)->canvas);
+	context = gtk_widget_get_style_context (GTK_WIDGET (container));
 
 	text_rect = compute_text_rectangle (item, icon_rect, TRUE, BOUNDS_USAGE_FOR_DISPLAY);
 
@@ -1126,15 +1064,49 @@ draw_label_text (NautilusIconCanvasItem *item,
 
 	max_text_width = floor (nautilus_icon_canvas_item_get_max_text_width (item));
 
+	state = GTK_STATE_FLAG_NORMAL;
+	gtk_widget_style_get (GTK_WIDGET (container),
+			      "activate_prelight_icon_label", &prelight_label,
+			      NULL);
+
 	/* if the icon is highlighted, do some set-up */
-	if (needs_highlight && !details->is_renaming) {
-		draw_frame (item,
-                            cr,
-			    gtk_widget_has_focus (GTK_WIDGET (container)) ? &container->details->highlight_color_rgba : &container->details->active_color_rgba,
-			    is_rtl_label_beside ? text_rect.x0 + item->details->text_dx : text_rect.x0,
-			    text_rect.y0,
-			    is_rtl_label_beside ? text_rect.x1 - text_rect.x0 - item->details->text_dx : text_rect.x1 - text_rect.x0,
-			    text_rect.y1 - text_rect.y0);
+	if (needs_highlight &&
+	    !details->is_renaming) {
+		if (gtk_widget_has_focus (GTK_WIDGET (container))) {
+			state |= GTK_STATE_FLAG_SELECTED;
+		} else {
+			state |= GTK_STATE_FLAG_ACTIVE;
+		}
+
+		frame_x = is_rtl_label_beside ? text_rect.x0 + item->details->text_dx : text_rect.x0;
+		frame_y = text_rect.y0;
+		frame_w = is_rtl_label_beside ? text_rect.x1 - text_rect.x0 - item->details->text_dx : text_rect.x1 - text_rect.x0;
+		frame_h = text_rect.y1 - text_rect.y0;
+	} else if (!needs_highlight && have_editable &&
+		   details->text_width > 0 && details->text_height > 0 &&
+		   prelight_label && item->details->is_prelit) {
+		state |= GTK_STATE_FLAG_PRELIGHT;
+
+		frame_x = text_rect.x0;
+		frame_y = text_rect.y0;
+		frame_w = text_rect.x1 - text_rect.x0;
+		frame_h = text_rect.y1 - text_rect.y0;
+	} else {
+		draw_frame = FALSE;
+	}
+
+	if (draw_frame) {
+		gtk_style_context_save (context);
+		gtk_style_context_set_state (context, state);
+
+		gtk_render_frame (context, cr,
+				  frame_x, frame_y,
+				  frame_w, frame_h);
+		gtk_render_background (context, cr,
+				       frame_x, frame_y,
+				       frame_w, frame_h);
+
+		gtk_style_context_restore (context);
 	}
 
 	if (container->details->label_position == NAUTILUS_ICON_LABEL_POSITION_BESIDE) {
@@ -1143,72 +1115,73 @@ draw_label_text (NautilusIconCanvasItem *item,
 		x = text_rect.x0 + ((text_rect.x1 - text_rect.x0) - max_text_width) / 2;
 	}
 	
-	if (have_editable) {
+	if (have_editable &&
+	    !details->is_renaming) {
+		state = GTK_STATE_FLAG_NORMAL;
+
+		if (prelight_label && item->details->is_prelit) {
+			state |= GTK_STATE_FLAG_PRELIGHT;
+		}
+
+		if (needs_highlight && gtk_widget_has_focus (GTK_WIDGET (container))) {
+			state |= GTK_STATE_FLAG_SELECTED;
+		} else if (needs_highlight) {
+			state |= GTK_STATE_FLAG_ACTIVE;
+		}
+
 		editable_layout = get_label_layout (&item->details->editable_text_layout, item, item->details->editable_text);
 		prepare_pango_layout_for_draw (item, editable_layout);
 
-		gtk_widget_style_get (GTK_WIDGET (container),
-				      "activate_prelight_icon_label", &prelight_label,
-				      NULL);
-		if (!needs_highlight && details->text_width > 0 && details->text_height > 0) {
-			if (prelight_label && item->details->is_prelit) {
-				draw_frame (item, 
-					    cr,
-					    &container->details->prelight_color_rgba,
-					    text_rect.x0,
-					    text_rect.y0,
-					    text_rect.x1 - text_rect.x0,
-					    text_rect.y1 - text_rect.y0);
-			}
-		}
-		
-		nautilus_icon_container_get_label_color
-			(NAUTILUS_ICON_CONTAINER (canvas_item->canvas),
-			 &label_color, TRUE, needs_highlight,
-			 prelight_label & item->details->is_prelit);
+		gtk_style_context_save (context);
+		gtk_style_context_set_state (context, state);
 
-		draw_label_layout (item, cr,
-				   editable_layout, needs_highlight,
-				   &label_color,
-				   x,
-				   text_rect.y0 + TEXT_BACK_PADDING_Y);
+		gtk_render_layout (context, cr,
+				   x, text_rect.y0 + TEXT_BACK_PADDING_Y,
+				   editable_layout);
+
+		gtk_style_context_restore (context);
 	}
 
-	if (have_additional) {
+	if (have_additional &&
+	    !details->is_renaming) {
+		state = GTK_STATE_FLAG_NORMAL;
+
+		if (needs_highlight && gtk_widget_has_focus (GTK_WIDGET (container))) {
+			state |= GTK_STATE_FLAG_SELECTED;
+		} else if (needs_highlight) {
+			state |= GTK_STATE_FLAG_ACTIVE;
+		}
+
 		additional_layout = get_label_layout (&item->details->additional_text_layout, item, item->details->additional_text);
 		prepare_pango_layout_for_draw (item, additional_layout);
 
-		nautilus_icon_container_get_label_color
-			(NAUTILUS_ICON_CONTAINER (canvas_item->canvas),
-			 &label_color, FALSE, needs_highlight,
-			 FALSE);
-		
-		draw_label_layout (item, cr,
-				   additional_layout, needs_highlight,
-				   &label_color,
-				   x,
-				   text_rect.y0 + details->editable_text_height + LABEL_LINE_SPACING + TEXT_BACK_PADDING_Y);
+		gtk_style_context_save (context);
+		gtk_style_context_set_state (context, state);
+		gtk_style_context_add_class (context, "dim-label");
+
+		gtk_render_layout (context, cr,
+				   x, text_rect.y0 + details->editable_text_height + LABEL_LINE_SPACING + TEXT_BACK_PADDING_Y,
+				   additional_layout);
 	}
 
 	if (item->details->is_highlighted_as_keyboard_focus) {
-		GtkStyleContext *style;
+		if (needs_highlight) {
+			state = GTK_STATE_FLAG_SELECTED;
+		} else {
+			state = GTK_STATE_FLAG_ACTIVE;
+		}
 
-		style = gtk_widget_get_style_context (GTK_WIDGET (EEL_CANVAS_ITEM (item)->canvas));
-
-		gtk_style_context_save (style);
-		gtk_style_context_add_class (style, "icon-container");
-		gtk_style_context_set_state (style,
-					     needs_highlight ?
-					     GTK_STATE_FLAG_SELECTED : GTK_STATE_FLAG_ACTIVE);
+		gtk_style_context_save (context);
+		gtk_style_context_set_state (context, state);
 					     
-		gtk_render_focus (style,
+		gtk_render_focus (context,
 				  cr,
 				  text_rect.x0,
 				  text_rect.y0,
 				  text_rect.x1 - text_rect.x0,
 				  text_rect.y1 - text_rect.y0);
 
-		gtk_style_context_restore (style);
+		gtk_style_context_restore (context);
 	}
 
 	if (editable_layout != NULL) {
@@ -1260,15 +1233,16 @@ static GdkPixbuf *
 get_knob_pixbuf (void)
 {
 	GdkPixbuf *knob_pixbuf;
-	char *knob_filename;
 
 	knob_pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
 						"stock-nautilus-knob",
 						8, 0, NULL);
 	if (!knob_pixbuf) {
-		knob_filename = nautilus_pixmap_file ("knob.png");
-		knob_pixbuf = gdk_pixbuf_new_from_file (knob_filename, NULL);
-		g_free (knob_filename);
+		GInputStream *stream = g_resources_open_stream ("/org/gnome/nautilus/icons/knob.png", 0, NULL);
+		if (stream != NULL) {
+			knob_pixbuf = gdk_pixbuf_new_from_stream (stream, NULL, NULL);
+			g_object_unref (stream);
+		}
 	}
 
 	return knob_pixbuf;
@@ -1338,6 +1312,8 @@ real_map_pixbuf (NautilusIconCanvasItem *icon_item)
 {
 	EelCanvas *canvas;
 	GdkPixbuf *temp_pixbuf, *old_pixbuf;
+	GtkStyleContext *style;
+	GdkRGBA color;
 	
 	temp_pixbuf = icon_item->details->pixbuf;
 	canvas = EEL_CANVAS_ITEM(icon_item)->canvas;
@@ -1354,15 +1330,16 @@ real_map_pixbuf (NautilusIconCanvasItem *icon_item)
 
 	if (icon_item->details->is_highlighted_for_selection
 	    || icon_item->details->is_highlighted_for_drop) {
-		GdkRGBA *color;
+		style = gtk_widget_get_style_context (GTK_WIDGET (canvas));
+
+		if (gtk_widget_has_focus (GTK_WIDGET (canvas))) {
+			gtk_style_context_get_background_color (style, GTK_STATE_FLAG_SELECTED, &color);
+		} else {
+			gtk_style_context_get_background_color (style, GTK_STATE_FLAG_ACTIVE, &color);	
+		}
 
 		old_pixbuf = temp_pixbuf;
-
-		color =  gtk_widget_has_focus (GTK_WIDGET (canvas)) ?
-			&NAUTILUS_ICON_CONTAINER (canvas)->details->highlight_color_rgba :
-			&NAUTILUS_ICON_CONTAINER (canvas)->details->active_color_rgba;
-
-		temp_pixbuf = eel_create_colorized_pixbuf (temp_pixbuf, color);
+		temp_pixbuf = eel_create_colorized_pixbuf (temp_pixbuf, &color);
 
 		g_object_unref (old_pixbuf);
 	}
@@ -1403,17 +1380,21 @@ draw_embedded_text (NautilusIconCanvasItem *item,
 	PangoLayout *layout;
 	PangoContext *context;
 	PangoFontDescription *desc;
-	
+	GtkWidget *widget;
+	GtkStyleContext *style_context;
+
 	if (item->details->embedded_text == NULL ||
 	    item->details->embedded_text_rect.width == 0 ||
 	    item->details->embedded_text_rect.height == 0) {
 		return;
 	}
 
+	widget = GTK_WIDGET (EEL_CANVAS_ITEM (item)->canvas);
+
 	if (item->details->embedded_text_layout != NULL) {
 		layout = g_object_ref (item->details->embedded_text_layout);
 	} else {
-		context = gtk_widget_get_pango_context (GTK_WIDGET (EEL_CANVAS_ITEM (item)->canvas));
+		context = gtk_widget_get_pango_context (widget);
 		layout = pango_layout_new (context);
 		pango_layout_set_text (layout, item->details->embedded_text, -1);
 		
@@ -1426,6 +1407,10 @@ draw_embedded_text (NautilusIconCanvasItem *item,
 		}
 	}
 
+	style_context = gtk_widget_get_style_context (widget);
+	gtk_style_context_save (style_context);
+	gtk_style_context_add_class (style_context, "icon-embedded-text");
+
 	cairo_save (cr);
 
 	cairo_rectangle (cr,
@@ -1435,12 +1420,12 @@ draw_embedded_text (NautilusIconCanvasItem *item,
 			 item->details->embedded_text_rect.height);
 	cairo_clip (cr);
 
-	cairo_set_source_rgb (cr, 0, 0, 0);
-	cairo_move_to (cr, 
-		       x + item->details->embedded_text_rect.x,
-		       y + item->details->embedded_text_rect.y);
-	pango_cairo_show_layout (cr, layout);
+	gtk_render_layout (style_context, cr,
+			   x + item->details->embedded_text_rect.x,
+			   y + item->details->embedded_text_rect.y,
+			   layout);
 
+	gtk_style_context_restore (style_context);
 	cairo_restore (cr);
 }
 
@@ -1450,12 +1435,14 @@ nautilus_icon_canvas_item_draw (EelCanvasItem *item,
                                 cairo_t *cr,
                                 cairo_region_t *region)
 {
+	NautilusIconContainer *container;
 	NautilusIconCanvasItem *icon_item;
 	NautilusIconCanvasItemDetails *details;
 	EelIRect icon_rect;
 	GdkPixbuf *temp_pixbuf;
-	GdkRectangle pixbuf_rect;
-			
+	GtkStyleContext *context;
+
+	container = NAUTILUS_ICON_CONTAINER (item->canvas);
 	icon_item = NAUTILUS_ICON_CANVAS_ITEM (item);
 	details = icon_item->details;
 
@@ -1464,21 +1451,16 @@ nautilus_icon_canvas_item_draw (EelCanvasItem *item,
 		return;
 	}
 
-	icon_rect = icon_item->details->canvas_rect;
-	
-	/* if the pre-lit or selection flag is set, make a pre-lit or darkened pixbuf and draw that instead */
-	/* and colorize normal pixbuf if rc wants that */
-	temp_pixbuf = map_pixbuf (icon_item);
-	pixbuf_rect.x = icon_rect.x0;
-	pixbuf_rect.y = icon_rect.y0;
-	pixbuf_rect.width = gdk_pixbuf_get_width (temp_pixbuf);
-	pixbuf_rect.height = gdk_pixbuf_get_height (temp_pixbuf);
+	context = gtk_widget_get_style_context (GTK_WIDGET (container));
+	gtk_style_context_save (context);
+	gtk_style_context_add_class (context, "nautilus-canvas-item");
 
-        cairo_save (cr);
-	gdk_cairo_set_source_pixbuf (cr, temp_pixbuf, pixbuf_rect.x, pixbuf_rect.y);
-	gdk_cairo_rectangle (cr, &pixbuf_rect);
-	cairo_fill (cr);
-	cairo_restore (cr);
+	icon_rect = icon_item->details->canvas_rect;
+	temp_pixbuf = map_pixbuf (icon_item);
+
+	gtk_render_icon (context, cr,
+			 temp_pixbuf,
+			 icon_rect.x0, icon_rect.y0);
 	g_object_unref (temp_pixbuf);
 
 	draw_embedded_text (icon_item, cr, icon_rect.x0, icon_rect.y0);
@@ -1488,6 +1470,8 @@ nautilus_icon_canvas_item_draw (EelCanvasItem *item,
 	
 	/* Draw the label text. */
 	draw_label_text (icon_item, cr, icon_rect);
+
+	gtk_style_context_restore (context);
 }
 
 #define ZERO_WIDTH_SPACE "\xE2\x80\x8B"
@@ -1589,37 +1573,6 @@ get_label_layout (PangoLayout **layout_cache,
 	return layout;
 }
 
-static void
-draw_label_layout (NautilusIconCanvasItem *item,
-		   cairo_t *cr,
-		   PangoLayout *layout,
-		   gboolean highlight,
-		   GdkRGBA *label_color,
-		   int x,
-		   int y)
-{
-	GdkRGBA black = { 0, 0, 0, 1 };
-
-	if (item->details->is_renaming) {
-		return;
-	}
-
-	if (!highlight && (NAUTILUS_ICON_CONTAINER (EEL_CANVAS_ITEM (item)->canvas)->details->use_drop_shadows)) {
-		/* draw a drop shadow */
-		eel_cairo_draw_layout_with_drop_shadow (cr,
-							label_color,
-							&black,
-							x, y,
-							layout);
-	} else {
-                cairo_save (cr);
-		gdk_cairo_set_source_rgba (cr, label_color);
-		cairo_move_to (cr, x, y);
-		pango_cairo_show_layout (cr, layout);
-		cairo_restore (cr);
-	}
-}
-
 /* handle events */
 
 static int
