@@ -34,11 +34,6 @@
 #include "nautilus-view-factory.h"
 
 #include <stdlib.h>
-#include <eel/eel-glib-extensions.h>
-#include <eel/eel-gtk-extensions.h>
-#include <eel/eel-gtk-macros.h>
-#include <eel/eel-stock-dialogs.h>
-#include <eel/eel-string.h>
 #include <eel/eel-vfs-extensions.h>
 #include <errno.h>
 #include <fcntl.h>
@@ -358,12 +353,6 @@ action_unstretch_callback (GtkAction *action,
 
 static void
 nautilus_icon_view_clean_up (NautilusIconView *icon_view)
-{
-	EEL_CALL_METHOD (NAUTILUS_ICON_VIEW_CLASS, icon_view, clean_up, (icon_view));
-}
-
-static void
-nautilus_icon_view_real_clean_up (NautilusIconView *icon_view)
 {
 	NautilusIconContainer *icon_container;
 	gboolean saved_sort_reversed;
@@ -666,13 +655,18 @@ static char *
 nautilus_icon_view_get_directory_sort_by (NautilusIconView *icon_view,
 					  NautilusFile *file)
 {
+	const SortCriterion *default_sort_criterion;
+
 	if (!nautilus_icon_view_supports_auto_layout (icon_view)) {
 		return g_strdup ("name");
 	}
 
-	return EEL_CALL_METHOD_WITH_RETURN_VALUE
-		(NAUTILUS_ICON_VIEW_CLASS, icon_view,
-		 get_directory_sort_by, (icon_view, file));
+	default_sort_criterion = get_sort_criterion_by_sort_type (get_default_sort_order (file, NULL));
+	g_return_val_if_fail (default_sort_criterion != NULL, NULL);
+
+	return nautilus_file_get_metadata
+		(file, NAUTILUS_METADATA_KEY_ICON_VIEW_SORT_BY,
+		 default_sort_criterion->metadata_text);
 }
 
 static NautilusFileSortType
@@ -701,38 +695,17 @@ get_default_sort_order (NautilusFile *file, gboolean *reversed)
 	return retval;
 }
 
-static char *
-nautilus_icon_view_real_get_directory_sort_by (NautilusIconView *icon_view,
-					       NautilusFile *file)
-{
-	const SortCriterion *default_sort_criterion;
-	default_sort_criterion = get_sort_criterion_by_sort_type (get_default_sort_order (file, NULL));
-	g_return_val_if_fail (default_sort_criterion != NULL, NULL);
-
-	return nautilus_file_get_metadata
-		(file, NAUTILUS_METADATA_KEY_ICON_VIEW_SORT_BY,
-		 default_sort_criterion->metadata_text);
-}
-
 static void
 nautilus_icon_view_set_directory_sort_by (NautilusIconView *icon_view, 
 					  NautilusFile *file, 
 					  const char *sort_by)
 {
+	const SortCriterion *default_sort_criterion;
+
 	if (!nautilus_icon_view_supports_auto_layout (icon_view)) {
 		return;
 	}
 
-	EEL_CALL_METHOD (NAUTILUS_ICON_VIEW_CLASS, icon_view,
-			 set_directory_sort_by, (icon_view, file, sort_by));
-}
-
-static void
-nautilus_icon_view_real_set_directory_sort_by (NautilusIconView *icon_view,
-					       NautilusFile *file,
-					       const char *sort_by)
-{
-	const SortCriterion *default_sort_criterion;
 	default_sort_criterion = get_sort_criterion_by_sort_type (get_default_sort_order (file, NULL));
 	g_return_if_fail (default_sort_criterion != NULL);
 
@@ -746,21 +719,12 @@ static gboolean
 nautilus_icon_view_get_directory_sort_reversed (NautilusIconView *icon_view,
 						NautilusFile *file)
 {
+	gboolean reversed;
+
 	if (!nautilus_icon_view_supports_auto_layout (icon_view)) {
 		return FALSE;
 	}
 
-	return EEL_CALL_METHOD_WITH_RETURN_VALUE
-		(NAUTILUS_ICON_VIEW_CLASS, icon_view,
-		 get_directory_sort_reversed, (icon_view, file));
-}
-
-static gboolean
-nautilus_icon_view_real_get_directory_sort_reversed (NautilusIconView *icon_view,
-						     NautilusFile *file)
-{
-	gboolean reversed;
-
 	get_default_sort_order (file, &reversed);
 	return nautilus_file_get_boolean_metadata
 		(file,
@@ -773,22 +737,12 @@ nautilus_icon_view_set_directory_sort_reversed (NautilusIconView *icon_view,
 						NautilusFile *file,
 						gboolean sort_reversed)
 {
+	gboolean reversed;
+
 	if (!nautilus_icon_view_supports_auto_layout (icon_view)) {
 		return;
 	}
 
-	EEL_CALL_METHOD (NAUTILUS_ICON_VIEW_CLASS, icon_view,
-			 set_directory_sort_reversed,
-			 (icon_view, file, sort_reversed));
-}
-
-static void
-nautilus_icon_view_real_set_directory_sort_reversed (NautilusIconView *icon_view,
-						     NautilusFile *file,
-						     gboolean sort_reversed)
-{
-	gboolean reversed;
-
 	get_default_sort_order (file, &reversed);
 	nautilus_file_set_boolean_metadata
 		(file,
@@ -843,15 +797,6 @@ nautilus_icon_view_get_directory_auto_layout (NautilusIconView *icon_view,
 		return TRUE;
 	}
 
-	return EEL_CALL_METHOD_WITH_RETURN_VALUE
-		(NAUTILUS_ICON_VIEW_CLASS, icon_view,
-		 get_directory_auto_layout, (icon_view, file));
-}
-
-static gboolean
-nautilus_icon_view_real_get_directory_auto_layout (NautilusIconView *icon_view,
-						   NautilusFile *file)
-{
 	return nautilus_file_get_boolean_metadata
 		(file, NAUTILUS_METADATA_KEY_ICON_VIEW_AUTO_LAYOUT, TRUE);
 }
@@ -866,19 +811,6 @@ nautilus_icon_view_set_directory_auto_layout (NautilusIconView *icon_view,
 		return;
 	}
 
-	EEL_CALL_METHOD (NAUTILUS_ICON_VIEW_CLASS, icon_view,
-			 set_directory_auto_layout, (icon_view, file, auto_layout));
-}
-
-static void
-nautilus_icon_view_real_set_directory_auto_layout (NautilusIconView *icon_view,
-						   NautilusFile *file,
-						   gboolean auto_layout)
-{
-	if (!nautilus_icon_view_supports_manual_layout (icon_view)) {
-		return;
-	}
-
 	nautilus_file_set_boolean_metadata
 		(file, NAUTILUS_METADATA_KEY_ICON_VIEW_AUTO_LAYOUT,
 		 TRUE,
@@ -1424,7 +1356,6 @@ nautilus_icon_view_merge_menus (NautilusView *view)
 	GtkUIManager *ui_manager;
 	GtkActionGroup *action_group;
 	GtkAction *action;
-	const char *ui;
 	
         g_assert (NAUTILUS_IS_ICON_VIEW (view));
 
@@ -1453,9 +1384,8 @@ nautilus_icon_view_merge_menus (NautilusView *view)
 	gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
 	g_object_unref (action_group); /* owned by ui manager */
 
-	ui = nautilus_ui_string_get ("nautilus-icon-view-ui.xml");
 	icon_view->details->icon_merge_id =
-		gtk_ui_manager_add_ui_from_string (ui_manager, ui, -1, NULL);
+		gtk_ui_manager_add_ui_from_resource (ui_manager, "/org/gnome/nautilus/nautilus-icon-view-ui.xml", NULL);
 
 	/* Do one-time state-setting here; context-dependent state-setting
 	 * is done in update_menus.
@@ -2575,14 +2505,6 @@ nautilus_icon_view_class_init (NautilusIconViewClass *klass)
 	nautilus_view_class->get_first_visible_file = icon_view_get_first_visible_file;
 	nautilus_view_class->scroll_to_file = icon_view_scroll_to_file;
 
-	klass->clean_up = nautilus_icon_view_real_clean_up;
-        klass->get_directory_auto_layout = nautilus_icon_view_real_get_directory_auto_layout;
-        klass->get_directory_sort_by = nautilus_icon_view_real_get_directory_sort_by;
-        klass->get_directory_sort_reversed = nautilus_icon_view_real_get_directory_sort_reversed;
-        klass->set_directory_auto_layout = nautilus_icon_view_real_set_directory_auto_layout;
-        klass->set_directory_sort_by = nautilus_icon_view_real_set_directory_sort_by;
-        klass->set_directory_sort_reversed = nautilus_icon_view_real_set_directory_sort_reversed;
-
 	properties[PROP_COMPACT] =
 		g_param_spec_boolean ("compact",
 				      "Compact",
