@@ -65,7 +65,6 @@ typedef struct {
 	GtkCellRenderer    *eject_icon_cell_renderer;
 	char 	           *uri;
 	GtkListStore       *store;
-	GtkTreeModel       *filter_model;
 	NautilusWindow *window;
 	NautilusBookmarkList *bookmarks;
 	GVolumeMonitor *volume_monitor;
@@ -188,30 +187,24 @@ static const GtkTargetEntry nautilus_shortcuts_drop_targets [] = {
 
 /* Drag and drop interface declarations */
 typedef struct {
-  GtkTreeModelFilter parent;
+  GtkListStore parent;
 
   NautilusPlacesSidebar *sidebar;
-} NautilusShortcutsModelFilter;
+} NautilusShortcutsModel;
 
 typedef struct {
-  GtkTreeModelFilterClass parent_class;
-} NautilusShortcutsModelFilterClass;
+  GtkListStoreClass parent_class;
+} NautilusShortcutsModelClass;
 
-#define NAUTILUS_SHORTCUTS_MODEL_FILTER_TYPE (_nautilus_shortcuts_model_filter_get_type ())
-#define NAUTILUS_SHORTCUTS_MODEL_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), NAUTILUS_SHORTCUTS_MODEL_FILTER_TYPE, NautilusShortcutsModelFilter))
+#define NAUTILUS_TYPE_SHORTCUTS_MODEL (_nautilus_shortcuts_model_get_type ())
+#define NAUTILUS_SHORTCUTS_MODEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), NAUTILUS_SHORTCUTS_MODEL_TYPE, NautilusShortcutsModel))
 
-GType _nautilus_shortcuts_model_filter_get_type (void);
-static void nautilus_shortcuts_model_filter_drag_source_iface_init (GtkTreeDragSourceIface *iface);
-
-G_DEFINE_TYPE_WITH_CODE (NautilusShortcutsModelFilter,
-			 _nautilus_shortcuts_model_filter,
-			 GTK_TYPE_TREE_MODEL_FILTER,
+GType _nautilus_shortcuts_model_get_type (void);
+static void _nautilus_shortcuts_model_drag_source_init (GtkTreeDragSourceIface *iface);
+G_DEFINE_TYPE_WITH_CODE (NautilusShortcutsModel, _nautilus_shortcuts_model, GTK_TYPE_LIST_STORE,
 			 G_IMPLEMENT_INTERFACE (GTK_TYPE_TREE_DRAG_SOURCE,
-						nautilus_shortcuts_model_filter_drag_source_iface_init));
-
-static GtkTreeModel *nautilus_shortcuts_model_filter_new (NautilusPlacesSidebar *sidebar,
-							  GtkTreeModel          *child_model,
-							  GtkTreePath           *root);
+						_nautilus_shortcuts_model_drag_source_init));
+static GtkListStore *nautilus_shortcuts_model_new (NautilusPlacesSidebar *sidebar);
 
 G_DEFINE_TYPE (NautilusPlacesSidebar, nautilus_places_sidebar, GTK_TYPE_SCROLLED_WINDOW);
 
@@ -307,7 +300,7 @@ add_heading (NautilusPlacesSidebar *sidebar,
 	     SectionType section_type,
 	     const gchar *title)
 {
-	GtkTreeIter iter, child_iter;
+	GtkTreeIter iter;
 
 	gtk_list_store_append (sidebar->store, &iter);
 	gtk_list_store_set (sidebar->store, &iter,
@@ -318,12 +311,7 @@ add_heading (NautilusPlacesSidebar *sidebar,
 			    PLACES_SIDEBAR_COLUMN_NO_EJECT, TRUE,
 			    -1);
 
-	gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER (sidebar->filter_model));
-	gtk_tree_model_filter_convert_child_iter_to_iter (GTK_TREE_MODEL_FILTER (sidebar->filter_model),
-							  &child_iter,
-							  &iter);
-
-	return child_iter;
+	return iter;
 }
 
 static void
@@ -352,7 +340,7 @@ check_heading_for_section (NautilusPlacesSidebar *sidebar,
 	}
 }
 
-static GtkTreeIter
+static void
 add_place (NautilusPlacesSidebar *sidebar,
 	   PlaceType place_type,
 	   SectionType section_type,
@@ -366,7 +354,7 @@ add_place (NautilusPlacesSidebar *sidebar,
 	   const char *tooltip)
 {
 	GdkPixbuf            *pixbuf;
-	GtkTreeIter           iter, child_iter;
+	GtkTreeIter           iter;
 	GdkPixbuf	     *eject;
 	NautilusIconInfo *icon_info;
 	int icon_size;
@@ -421,37 +409,58 @@ add_place (NautilusPlacesSidebar *sidebar,
 	if (pixbuf != NULL) {
 		g_object_unref (pixbuf);
 	}
-	gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER (sidebar->filter_model));
-	gtk_tree_model_filter_convert_child_iter_to_iter (GTK_TREE_MODEL_FILTER (sidebar->filter_model),
-							  &child_iter,
-							  &iter);
-	return child_iter;
+}
+
+typedef struct {
+	const gchar *location;
+	const gchar *last_uri;
+	NautilusPlacesSidebar *sidebar;
+	GtkTreePath *path;
+} RestoreLocationData;
+
+static gboolean
+restore_selection_foreach (GtkTreeModel *model,
+			   GtkTreePath *path,
+			   GtkTreeIter *iter,
+			   gpointer user_data)
+{
+	RestoreLocationData *data = user_data;
+	gchar *uri;
+
+	gtk_tree_model_get (model, iter,
+			    PLACES_SIDEBAR_COLUMN_URI, &uri,
+			    -1);
+
+	if (g_strcmp0 (uri, data->last_uri) == 0 ||
+	    g_strcmp0 (uri, data->location) == 0) {
+		data->path = gtk_tree_path_copy (path);
+	}
+
+	g_free (uri);
+
+	return (data->path != NULL);
 }
 
 static void
-compare_for_selection (NautilusPlacesSidebar *sidebar,
-		       const gchar *location,
-		       const gchar *added_uri,
-		       const gchar *last_uri,
-		       GtkTreeIter *iter,
-		       GtkTreePath **path)
+sidebar_update_restore_selection (NautilusPlacesSidebar *sidebar,
+				  const gchar *location,
+				  const gchar *last_uri)
 {
-	int res;
+	RestoreLocationData data;
+	GtkTreeSelection *selection;
 
-	res = g_strcmp0 (added_uri, last_uri);
+	data.location = location;
+	data.last_uri = last_uri;
+	data.sidebar = sidebar;
+	data.path = NULL;
 
-	if (res == 0) {
-		/* last_uri always comes first */
-		if (*path != NULL) {
-			gtk_tree_path_free (*path);
-		}
-		*path = gtk_tree_model_get_path (sidebar->filter_model,
-						 iter);
-	} else if (g_strcmp0 (location, added_uri) == 0) {
-		if (*path == NULL) {
-			*path = gtk_tree_model_get_path (sidebar->filter_model,
-							 iter);
-		}
+	gtk_tree_model_foreach (GTK_TREE_MODEL (sidebar->store),
+				restore_selection_foreach, &data);
+
+	if (data.path != NULL) {
+		selection = gtk_tree_view_get_selection (sidebar->tree_view);
+		gtk_tree_selection_select_path (selection, data.path);
+		gtk_tree_path_free (data.path);
 	}
 }
 
@@ -461,7 +470,6 @@ update_places (NautilusPlacesSidebar *sidebar)
 	NautilusBookmark *bookmark;
 	GtkTreeSelection *selection;
 	GtkTreeIter last_iter;
-	GtkTreePath *select_path;
 	GtkTreeModel *model;
 	GVolumeMonitor *volume_monitor;
 	GList *mounts, *l, *ll;
@@ -484,7 +492,6 @@ update_places (NautilusPlacesSidebar *sidebar)
 
 	model = NULL;
 	last_uri = NULL;
-	select_path = NULL;
 
 	selection = gtk_tree_view_get_selection (sidebar->tree_view);
 	if (gtk_tree_selection_get_selected (selection, &model, &last_iter)) {
@@ -521,13 +528,10 @@ update_places (NautilusPlacesSidebar *sidebar)
 					name = g_mount_get_name (mount);
 					tooltip = g_file_get_parse_name (root);
 
-					last_iter = add_place (sidebar, PLACES_MOUNTED_VOLUME,
-							       SECTION_DEVICES,
-							       name, icon, mount_uri,
-							       drive, volume, mount, 0, tooltip);
-					compare_for_selection (sidebar,
-							       location, mount_uri, last_uri,
-							       &last_iter, &select_path);
+					add_place (sidebar, PLACES_MOUNTED_VOLUME,
+						   SECTION_DEVICES,
+						   name, icon, mount_uri,
+						   drive, volume, mount, 0, tooltip);
 					g_object_unref (root);
 					g_object_unref (mount);
 					g_object_unref (icon);
@@ -547,10 +551,10 @@ update_places (NautilusPlacesSidebar *sidebar)
 					name = g_volume_get_name (volume);
 					tooltip = g_strdup_printf (_("Mount and open %s"), name);
 
-					last_iter = add_place (sidebar, PLACES_MOUNTED_VOLUME,
-							       SECTION_DEVICES,
-							       name, icon, NULL,
-							       drive, volume, NULL, 0, tooltip);
+					add_place (sidebar, PLACES_MOUNTED_VOLUME,
+						   SECTION_DEVICES,
+						   name, icon, NULL,
+						   drive, volume, NULL, 0, tooltip);
 					g_object_unref (icon);
 					g_free (name);
 					g_free (tooltip);
@@ -572,10 +576,10 @@ update_places (NautilusPlacesSidebar *sidebar)
 				name = g_drive_get_name (drive);
 				tooltip = g_strdup_printf (_("Mount and open %s"), name);
 
-				last_iter = add_place (sidebar, PLACES_BUILT_IN,
-						       SECTION_DEVICES,
-						       name, icon, NULL,
-						       drive, NULL, NULL, 0, tooltip);
+				add_place (sidebar, PLACES_BUILT_IN,
+					   SECTION_DEVICES,
+					   name, icon, NULL,
+					   drive, NULL, NULL, 0, tooltip);
 				g_object_unref (icon);
 				g_free (tooltip);
 				g_free (name);
@@ -603,13 +607,10 @@ update_places (NautilusPlacesSidebar *sidebar)
 			tooltip = g_file_get_parse_name (root);
 			g_object_unref (root);
 			name = g_mount_get_name (mount);
-			last_iter = add_place (sidebar, PLACES_MOUNTED_VOLUME,
-					       SECTION_DEVICES,
-					       name, icon, mount_uri,
-					       NULL, volume, mount, 0, tooltip);
-			compare_for_selection (sidebar,
-					       location, mount_uri, last_uri,
-					       &last_iter, &select_path);
+			add_place (sidebar, PLACES_MOUNTED_VOLUME,
+				   SECTION_DEVICES,
+				   name, icon, mount_uri,
+				   NULL, volume, mount, 0, tooltip);
 			g_object_unref (mount);
 			g_object_unref (icon);
 			g_free (name);
@@ -619,10 +620,10 @@ update_places (NautilusPlacesSidebar *sidebar)
 			/* see comment above in why we add an icon for an unmounted mountable volume */
 			icon = g_volume_get_icon (volume);
 			name = g_volume_get_name (volume);
-			last_iter = add_place (sidebar, PLACES_MOUNTED_VOLUME,
-					       SECTION_DEVICES,
-					       name, icon, NULL,
-					       NULL, volume, NULL, 0, name);
+			add_place (sidebar, PLACES_MOUNTED_VOLUME,
+				   SECTION_DEVICES,
+				   name, icon, NULL,
+				   NULL, volume, NULL, 0, name);
 			g_object_unref (icon);
 			g_free (name);
 		}
@@ -655,38 +656,31 @@ update_places (NautilusPlacesSidebar *sidebar)
 		mount_uri = nautilus_bookmark_get_uri (bookmark);
 		tooltip = g_file_get_parse_name (root);
 
-		last_iter = add_place (sidebar, PLACES_BOOKMARK,
-				       SECTION_BOOKMARKS,
-				       bookmark_name, icon, mount_uri,
-				       NULL, NULL, NULL, index,
-				       tooltip);
-		compare_for_selection (sidebar,
-				       location, mount_uri, last_uri,
-				       &last_iter, &select_path);
-
+		add_place (sidebar, PLACES_BOOKMARK,
+			   SECTION_BOOKMARKS,
+			   bookmark_name, icon, mount_uri,
+			   NULL, NULL, NULL, index,
+			   tooltip);
 		g_object_unref (root);
 		g_object_unref (icon);
 		g_free (mount_uri);
 		g_free (tooltip);
 	}
 
-	last_iter = add_heading (sidebar, SECTION_COMPUTER,
-			       _("Computer"));
+	add_heading (sidebar, SECTION_COMPUTER,
+		     _("Computer"));
 
 	/* add built in bookmarks */
 
 	/* home folder */
 	mount_uri = nautilus_get_home_directory_uri ();
 	icon = g_themed_icon_new (NAUTILUS_ICON_HOME);
-	last_iter = add_place (sidebar, PLACES_BUILT_IN,
-			       SECTION_COMPUTER,
-			       _("Home"), icon,
-			       mount_uri, NULL, NULL, NULL, 0,
-			       _("Open your personal folder"));
+	add_place (sidebar, PLACES_BUILT_IN,
+		   SECTION_COMPUTER,
+		   _("Home"), icon,
+		   mount_uri, NULL, NULL, NULL, 0,
+		   _("Open your personal folder"));
 	g_object_unref (icon);
-	compare_for_selection (sidebar,
-			       location, mount_uri, last_uri,
-			       &last_iter, &select_path);
 	g_free (mount_uri);
 
 	if (should_show_desktop ()) {
@@ -694,15 +688,12 @@ update_places (NautilusPlacesSidebar *sidebar)
 		desktop_path = nautilus_get_desktop_directory ();
 		mount_uri = g_filename_to_uri (desktop_path, NULL, NULL);
 		icon = g_themed_icon_new (NAUTILUS_ICON_DESKTOP);
-		last_iter = add_place (sidebar, PLACES_BUILT_IN,
-				       SECTION_COMPUTER,
-				       _("Desktop"), icon,
-				       mount_uri, NULL, NULL, NULL, 0,
-				       _("Open the contents of your desktop in a folder"));
+		add_place (sidebar, PLACES_BUILT_IN,
+			   SECTION_COMPUTER,
+			   _("Desktop"), icon,
+			   mount_uri, NULL, NULL, NULL, 0,
+			   _("Open the contents of your desktop in a folder"));
 		g_object_unref (icon);
-		compare_for_selection (sidebar,
-				       location, mount_uri, last_uri,
-				       &last_iter, &select_path);
 		g_free (mount_uri);
 		g_free (desktop_path);
 	}
@@ -733,14 +724,11 @@ update_places (NautilusPlacesSidebar *sidebar)
 		mount_uri = g_file_get_uri (root);
 		tooltip = g_file_get_parse_name (root);
 
-		last_iter = add_place (sidebar, PLACES_XDG_DIR,
-				       SECTION_COMPUTER,
-				       name, icon, mount_uri,
-				       NULL, NULL, NULL, 0,
-				       tooltip);
-		compare_for_selection (sidebar,
-				       location, mount_uri, last_uri,
-				       &last_iter, &select_path);
+		add_place (sidebar, PLACES_XDG_DIR,
+			   SECTION_COMPUTER,
+			   name, icon, mount_uri,
+			   NULL, NULL, NULL, 0,
+			   tooltip);
 		g_free (name);
 		g_object_unref (root);
 		g_object_unref (icon);
@@ -775,13 +763,10 @@ update_places (NautilusPlacesSidebar *sidebar)
 		mount_uri = g_file_get_uri (root);
 		name = g_mount_get_name (mount);
 		tooltip = g_file_get_parse_name (root);
-		last_iter = add_place (sidebar, PLACES_MOUNTED_VOLUME,
-				       SECTION_COMPUTER,
-				       name, icon, mount_uri,
-				       NULL, NULL, mount, 0, tooltip);
-		compare_for_selection (sidebar,
-				       location, mount_uri, last_uri,
-				       &last_iter, &select_path);
+		add_place (sidebar, PLACES_MOUNTED_VOLUME,
+			   SECTION_COMPUTER,
+			   name, icon, mount_uri,
+			   NULL, NULL, mount, 0, tooltip);
 		g_object_unref (root);
 		g_object_unref (mount);
 		g_object_unref (icon);
@@ -794,31 +779,25 @@ update_places (NautilusPlacesSidebar *sidebar)
 	/* file system root */
  	mount_uri = "file:///"; /* No need to strdup */
 	icon = g_themed_icon_new (NAUTILUS_ICON_FILESYSTEM);
-	last_iter = add_place (sidebar, PLACES_BUILT_IN,
-			       SECTION_COMPUTER,
-			       _("File System"), icon,
-			       mount_uri, NULL, NULL, NULL, 0,
-			       _("Open the contents of the File System"));
+	add_place (sidebar, PLACES_BUILT_IN,
+		   SECTION_COMPUTER,
+		   _("File System"), icon,
+		   mount_uri, NULL, NULL, NULL, 0,
+		   _("Open the contents of the File System"));
 	g_object_unref (icon);
-	compare_for_selection (sidebar,
-			       location, mount_uri, last_uri,
-			       &last_iter, &select_path);
 
 	mount_uri = "trash:///"; /* No need to strdup */
 	icon = nautilus_trash_monitor_get_icon ();
-	last_iter = add_place (sidebar, PLACES_BUILT_IN,
-			       SECTION_COMPUTER,
-			       _("Trash"), icon, mount_uri,
-			       NULL, NULL, NULL, 0,
-			       _("Open the trash"));
-	compare_for_selection (sidebar,
-			       location, mount_uri, last_uri,
-			       &last_iter, &select_path);
+	add_place (sidebar, PLACES_BUILT_IN,
+		   SECTION_COMPUTER,
+		   _("Trash"), icon, mount_uri,
+		   NULL, NULL, NULL, 0,
+		   _("Open the trash"));
 	g_object_unref (icon);
 
 	/* network */
-	last_iter = add_heading (sidebar, SECTION_NETWORK,
-				 _("Network"));
+	add_heading (sidebar, SECTION_NETWORK,
+		     _("Network"));
 
 	network_mounts = g_list_reverse (network_mounts);
 	for (l = network_mounts; l != NULL; l = l->next) {
@@ -828,13 +807,10 @@ update_places (NautilusPlacesSidebar *sidebar)
 		mount_uri = g_file_get_uri (root);
 		name = g_mount_get_name (mount);
 		tooltip = g_file_get_parse_name (root);
-		last_iter = add_place (sidebar, PLACES_MOUNTED_VOLUME,
-				       SECTION_NETWORK,
-				       name, icon, mount_uri,
-				       NULL, NULL, mount, 0, tooltip);
-		compare_for_selection (sidebar,
-				       location, mount_uri, last_uri,
-				       &last_iter, &select_path);
+		add_place (sidebar, PLACES_MOUNTED_VOLUME,
+			   SECTION_NETWORK,
+			   name, icon, mount_uri,
+			   NULL, NULL, mount, 0, tooltip);
 		g_object_unref (root);
 		g_object_unref (mount);
 		g_object_unref (icon);
@@ -848,26 +824,17 @@ update_places (NautilusPlacesSidebar *sidebar)
 	/* network:// */
  	mount_uri = "network:///"; /* No need to strdup */
 	icon = g_themed_icon_new (NAUTILUS_ICON_NETWORK);
-	last_iter = add_place (sidebar, PLACES_BUILT_IN,
-			       SECTION_NETWORK,
-			       _("Browse Network"), icon,
-			       mount_uri, NULL, NULL, NULL, 0,
-			       _("Browse the contents of the network"));
+	add_place (sidebar, PLACES_BUILT_IN,
+		   SECTION_NETWORK,
+		   _("Browse Network"), icon,
+		   mount_uri, NULL, NULL, NULL, 0,
+		   _("Browse the contents of the network"));
 	g_object_unref (icon);
-	compare_for_selection (sidebar,
-			       location, mount_uri, last_uri,
-			       &last_iter, &select_path);
-	
+
+	/* restore selection */
+	sidebar_update_restore_selection (sidebar, location, last_uri);
+
 	g_free (location);
-
-	if (select_path != NULL) {
-		gtk_tree_selection_select_path (selection, select_path);
-	}
-
-	if (select_path != NULL) {
-		gtk_tree_path_free (select_path);
-	}
-
 	g_free (last_uri);
 }
 
@@ -1049,10 +1016,11 @@ loading_uri_callback (NautilusWindow *window,
 		/* set selection if any place matches location */
 		selection = gtk_tree_view_get_selection (sidebar->tree_view);
 		gtk_tree_selection_unselect_all (selection);
-  		valid = gtk_tree_model_get_iter_first (sidebar->filter_model, &iter);
+  		valid = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (sidebar->store),
+						       &iter);
 
 		while (valid) {
-			gtk_tree_model_get (sidebar->filter_model, &iter, 
+			gtk_tree_model_get (GTK_TREE_MODEL (sidebar->store), &iter, 
 		 		       	    PLACES_SIDEBAR_COLUMN_URI, &uri,
 					    -1);
 			if (uri != NULL) {
@@ -1063,7 +1031,8 @@ loading_uri_callback (NautilusWindow *window,
 				}
 				g_free (uri);
 			}
-        	 	valid = gtk_tree_model_iter_next (sidebar->filter_model, &iter);
+        	 	valid = gtk_tree_model_iter_next (GTK_TREE_MODEL (sidebar->store),
+							  &iter);
 		}
     	}
 }
@@ -1239,9 +1208,9 @@ drag_motion_callback (GtkTreeView *tree_view,
 		if (sidebar->drag_list == NULL) {
 			action = 0;
 		} else {
-			gtk_tree_model_get_iter (sidebar->filter_model,
+			gtk_tree_model_get_iter (GTK_TREE_MODEL (sidebar->store),
 						 &iter, path);
-			gtk_tree_model_get (GTK_TREE_MODEL (sidebar->filter_model),
+			gtk_tree_model_get (GTK_TREE_MODEL (sidebar->store),
 					    &iter,
 					    PLACES_SIDEBAR_COLUMN_URI, &uri,
 					    -1);
@@ -1393,7 +1362,7 @@ reorder_bookmarks (NautilusPlacesSidebar *sidebar,
 		return;
 	}
 
-	gtk_tree_model_get (GTK_TREE_MODEL (sidebar->filter_model), &iter,
+	gtk_tree_model_get (GTK_TREE_MODEL (sidebar->store), &iter,
 			    PLACES_SIDEBAR_COLUMN_ROW_TYPE, &type,
 			    PLACES_SIDEBAR_COLUMN_INDEX, &old_position,
 			    -1);
@@ -1672,7 +1641,7 @@ bookmarks_check_popup_sensitivity (NautilusPlacesSidebar *sidebar)
 	}
 
 	if (get_selected_iter (sidebar, &iter)) {
-		gtk_tree_model_get (GTK_TREE_MODEL (sidebar->filter_model), &iter,
+		gtk_tree_model_get (GTK_TREE_MODEL (sidebar->store), &iter,
 				    PLACES_SIDEBAR_COLUMN_ROW_TYPE, &type,
 				    PLACES_SIDEBAR_COLUMN_DRIVE, &drive,
 				    PLACES_SIDEBAR_COLUMN_VOLUME, &volume,
@@ -1766,6 +1735,7 @@ bookmarks_selection_changed_cb (GtkTreeSelection      *selection,
 
 static void
 volume_mounted_cb (GVolume *volume,
+		   gboolean success,
 		   GObject *user_data)
 {
 	GMount *mount;
@@ -1992,7 +1962,7 @@ rename_selected_bookmark (NautilusPlacesSidebar *sidebar)
 	PlaceType type;
 	
 	if (get_selected_iter (sidebar, &iter)) {
-		gtk_tree_model_get (GTK_TREE_MODEL (sidebar->filter_model), &iter,
+		gtk_tree_model_get (GTK_TREE_MODEL (sidebar->store), &iter,
 				    PLACES_SIDEBAR_COLUMN_ROW_TYPE, &type,
 				    -1);
 
@@ -2000,7 +1970,7 @@ rename_selected_bookmark (NautilusPlacesSidebar *sidebar)
 			return;
 		}
 
-		path = gtk_tree_model_get_path (GTK_TREE_MODEL (sidebar->filter_model), &iter);
+		path = gtk_tree_model_get_path (GTK_TREE_MODEL (sidebar->store), &iter);
 		column = gtk_tree_view_get_column (GTK_TREE_VIEW (sidebar->tree_view), 0);
 		renderers = gtk_cell_layout_get_cells (GTK_CELL_LAYOUT (column));
 		cell = g_list_nth_data (renderers, 6);
@@ -2031,7 +2001,7 @@ remove_selected_bookmarks (NautilusPlacesSidebar *sidebar)
 		return;
 	}
 	
-	gtk_tree_model_get (GTK_TREE_MODEL (sidebar->filter_model), &iter,
+	gtk_tree_model_get (GTK_TREE_MODEL (sidebar->store), &iter,
 			    PLACES_SIDEBAR_COLUMN_ROW_TYPE, &type,
 			    -1);
 
@@ -2039,7 +2009,7 @@ remove_selected_bookmarks (NautilusPlacesSidebar *sidebar)
 		return;
 	}
 
-	gtk_tree_model_get (GTK_TREE_MODEL (sidebar->filter_model), &iter,
+	gtk_tree_model_get (GTK_TREE_MODEL (sidebar->store), &iter,
 			    PLACES_SIDEBAR_COLUMN_INDEX, &index,
 			    -1);
 
@@ -2064,7 +2034,7 @@ mount_shortcut_cb (GtkMenuItem           *item,
 		return;
 	}
 
-	gtk_tree_model_get (GTK_TREE_MODEL (sidebar->filter_model), &iter,
+	gtk_tree_model_get (GTK_TREE_MODEL (sidebar->store), &iter,
 			    PLACES_SIDEBAR_COLUMN_VOLUME, &volume,
 			    -1);
 
@@ -2104,7 +2074,7 @@ do_unmount_selection (NautilusPlacesSidebar *sidebar)
 		return;
 	}
 
-	gtk_tree_model_get (GTK_TREE_MODEL (sidebar->filter_model), &iter,
+	gtk_tree_model_get (GTK_TREE_MODEL (sidebar->store), &iter,
 			    PLACES_SIDEBAR_COLUMN_MOUNT, &mount,
 			    -1);
 
@@ -2240,7 +2210,7 @@ eject_shortcut_cb (GtkMenuItem           *item,
 		return;
 	}
 
-	gtk_tree_model_get (GTK_TREE_MODEL (sidebar->filter_model), &iter,
+	gtk_tree_model_get (GTK_TREE_MODEL (sidebar->store), &iter,
 			    PLACES_SIDEBAR_COLUMN_MOUNT, &mount,
 			    PLACES_SIDEBAR_COLUMN_VOLUME, &volume,
 			    PLACES_SIDEBAR_COLUMN_DRIVE, &drive,
@@ -2261,7 +2231,7 @@ eject_or_unmount_bookmark (NautilusPlacesSidebar *sidebar,
 	GDrive *drive;
 	gboolean ret;
 
-	model = GTK_TREE_MODEL (sidebar->filter_model);
+	model = GTK_TREE_MODEL (sidebar->store);
 
 	if (!path) {
 		return FALSE;
@@ -2309,7 +2279,7 @@ eject_or_unmount_selection (NautilusPlacesSidebar *sidebar)
 		return FALSE;
 	}
 
-	path = gtk_tree_model_get_path (GTK_TREE_MODEL (sidebar->filter_model), &iter);
+	path = gtk_tree_model_get_path (GTK_TREE_MODEL (sidebar->store), &iter);
 	if (path == NULL) {
 		return FALSE;
 	}
@@ -2356,7 +2326,7 @@ rescan_shortcut_cb (GtkMenuItem           *item,
 		return;
 	}
 
-	gtk_tree_model_get (GTK_TREE_MODEL (sidebar->filter_model), &iter,
+	gtk_tree_model_get (GTK_TREE_MODEL (sidebar->store), &iter,
 			    PLACES_SIDEBAR_COLUMN_DRIVE, &drive,
 			    -1);
 
@@ -2401,7 +2371,7 @@ start_shortcut_cb (GtkMenuItem           *item,
 		return;
 	}
 
-	gtk_tree_model_get (GTK_TREE_MODEL (sidebar->filter_model), &iter,
+	gtk_tree_model_get (GTK_TREE_MODEL (sidebar->store), &iter,
 			    PLACES_SIDEBAR_COLUMN_DRIVE, &drive,
 			    -1);
 
@@ -2456,7 +2426,7 @@ stop_shortcut_cb (GtkMenuItem           *item,
 		return;
 	}
 
-	gtk_tree_model_get (GTK_TREE_MODEL (sidebar->filter_model), &iter,
+	gtk_tree_model_get (GTK_TREE_MODEL (sidebar->store), &iter,
 			    PLACES_SIDEBAR_COLUMN_DRIVE, &drive,
 			    -1);
 
@@ -2877,11 +2847,11 @@ update_eject_buttons (NautilusPlacesSidebar *sidebar,
 	}
 
 	if (path) {
-		gtk_tree_model_get_iter (GTK_TREE_MODEL (sidebar->filter_model),
+		gtk_tree_model_get_iter (GTK_TREE_MODEL (sidebar->store),
 					 &iter,
 					 path);
 
-		gtk_tree_model_get (GTK_TREE_MODEL (sidebar->filter_model),
+		gtk_tree_model_get (GTK_TREE_MODEL (sidebar->store),
 				    &iter,
 				    PLACES_SIDEBAR_COLUMN_EJECT, &icon_visible,
 				    -1);
@@ -2900,7 +2870,6 @@ update_eject_buttons (NautilusPlacesSidebar *sidebar,
 					    &iter,
 					    PLACES_SIDEBAR_COLUMN_EJECT_ICON, get_eject_icon (sidebar, FALSE),
 					    -1);
-			gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER (sidebar->filter_model));
 
 			gtk_tree_path_free (sidebar->eject_highlight_path);
 			sidebar->eject_highlight_path = NULL;
@@ -2922,7 +2891,6 @@ update_eject_buttons (NautilusPlacesSidebar *sidebar,
 				    &iter,
 				    PLACES_SIDEBAR_COLUMN_EJECT_ICON, get_eject_icon (sidebar, TRUE),
 				    -1);
-		gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER (sidebar->filter_model));
 
 		sidebar->eject_highlight_path = gtk_tree_path_copy (path);
 	}
@@ -3017,8 +2985,8 @@ bookmarks_edited (GtkCellRenderer       *cell,
 	g_object_set (cell, "editable", FALSE, NULL);
 	
 	path = gtk_tree_path_new_from_string (path_string);
-	gtk_tree_model_get_iter (GTK_TREE_MODEL (sidebar->filter_model), &iter, path);
-	gtk_tree_model_get (GTK_TREE_MODEL (sidebar->filter_model), &iter,
+	gtk_tree_model_get_iter (GTK_TREE_MODEL (sidebar->store), &iter, path);
+	gtk_tree_model_get (GTK_TREE_MODEL (sidebar->store), &iter,
 		            PLACES_SIDEBAR_COLUMN_INDEX, &index,
 		            -1);
 	gtk_tree_path_free (path);
@@ -3311,23 +3279,7 @@ nautilus_places_sidebar_init (NautilusPlacesSidebar *sidebar)
 	gtk_tree_view_column_set_max_width (GTK_TREE_VIEW_COLUMN (col), NAUTILUS_ICON_SIZE_SMALLER);
 	gtk_tree_view_append_column (tree_view, col);
 
-	sidebar->store = gtk_list_store_new (PLACES_SIDEBAR_COLUMN_COUNT,
-					     G_TYPE_INT, 
-					     G_TYPE_STRING,
-					     G_TYPE_DRIVE,
-					     G_TYPE_VOLUME,
-					     G_TYPE_MOUNT,
-					     G_TYPE_STRING,
-					     GDK_TYPE_PIXBUF,
-					     G_TYPE_INT,
-					     G_TYPE_BOOLEAN,
-					     G_TYPE_BOOLEAN,
-					     G_TYPE_BOOLEAN,
-					     G_TYPE_STRING,
-					     GDK_TYPE_PIXBUF,
-					     G_TYPE_INT,
-					     G_TYPE_STRING);
-
+	sidebar->store = nautilus_shortcuts_model_new (sidebar);
 	gtk_tree_view_set_tooltip_column (tree_view, PLACES_SIDEBAR_COLUMN_TOOLTIP);
 	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (sidebar->store),
 					      PLACES_SIDEBAR_COLUMN_NAME,
@@ -3337,11 +3289,7 @@ nautilus_places_sidebar_init (NautilusPlacesSidebar *sidebar)
 					 places_sidebar_sort_func,
 					 sidebar, NULL);
 
-	sidebar->filter_model = nautilus_shortcuts_model_filter_new (sidebar,
-								     GTK_TREE_MODEL (sidebar->store),
-								     NULL);
-
-	gtk_tree_view_set_model (tree_view, sidebar->filter_model);
+	gtk_tree_view_set_model (tree_view, GTK_TREE_MODEL (sidebar->store));
 	gtk_container_add (GTK_CONTAINER (sidebar), GTK_WIDGET (tree_view));
 	gtk_widget_show (GTK_WIDGET (tree_view));
 
@@ -3435,7 +3383,6 @@ nautilus_places_sidebar_dispose (GObject *object)
 
 	g_clear_object (&sidebar->store);
 	g_clear_object (&sidebar->bookmarks);
-	g_clear_object (&sidebar->filter_model);
 
 	eel_remove_weak_pointer (&(sidebar->go_to_after_mount_slot));
 
@@ -3557,21 +3504,11 @@ nautilus_places_sidebar_new (NautilusWindow *window)
 
 /* Drag and drop interfaces */
 
-static void
-_nautilus_shortcuts_model_filter_class_init (NautilusShortcutsModelFilterClass *class)
-{
-}
-
-static void
-_nautilus_shortcuts_model_filter_init (NautilusShortcutsModelFilter *model)
-{
-	model->sidebar = NULL;
-}
-
 /* GtkTreeDragSource::row_draggable implementation for the shortcuts filter model */
+
 static gboolean
-nautilus_shortcuts_model_filter_row_draggable (GtkTreeDragSource *drag_source,
-					       GtkTreePath       *path)
+nautilus_shortcuts_model_row_draggable (GtkTreeDragSource *drag_source,
+					GtkTreePath       *path)
 {
 	GtkTreeModel *model;
 	GtkTreeIter iter;
@@ -3592,26 +3529,52 @@ nautilus_shortcuts_model_filter_row_draggable (GtkTreeDragSource *drag_source,
 	return FALSE;
 }
 
-/* Fill the GtkTreeDragSourceIface vtable */
 static void
-nautilus_shortcuts_model_filter_drag_source_iface_init (GtkTreeDragSourceIface *iface)
+_nautilus_shortcuts_model_class_init (NautilusShortcutsModelClass *klass)
 {
-	iface->row_draggable = nautilus_shortcuts_model_filter_row_draggable;
+
 }
 
-static GtkTreeModel *
-nautilus_shortcuts_model_filter_new (NautilusPlacesSidebar *sidebar,
-				     GtkTreeModel          *child_model,
-				     GtkTreePath           *root)
+static void
+_nautilus_shortcuts_model_init (NautilusShortcutsModel *model)
 {
-	NautilusShortcutsModelFilter *model;
+	model->sidebar = NULL;
+}
 
-	model = g_object_new (NAUTILUS_SHORTCUTS_MODEL_FILTER_TYPE,
-			      "child-model", child_model,
-			      "virtual-root", root,
-			      NULL);
+static void
+_nautilus_shortcuts_model_drag_source_init (GtkTreeDragSourceIface *iface)
+{
+	iface->row_draggable = nautilus_shortcuts_model_row_draggable;
+}
 
+static GtkListStore *
+nautilus_shortcuts_model_new (NautilusPlacesSidebar *sidebar)
+{
+	NautilusShortcutsModel *model;
+	GType model_types[PLACES_SIDEBAR_COLUMN_COUNT] = {
+		G_TYPE_INT, 
+		G_TYPE_STRING,
+		G_TYPE_DRIVE,
+		G_TYPE_VOLUME,
+		G_TYPE_MOUNT,
+		G_TYPE_STRING,
+		GDK_TYPE_PIXBUF,
+		G_TYPE_INT,
+		G_TYPE_BOOLEAN,
+		G_TYPE_BOOLEAN,
+		G_TYPE_BOOLEAN,
+		G_TYPE_STRING,
+		GDK_TYPE_PIXBUF,
+		G_TYPE_INT,
+		G_TYPE_STRING
+	};
+
+	model = g_object_new (NAUTILUS_TYPE_SHORTCUTS_MODEL, NULL);
 	model->sidebar = sidebar;
 
-	return GTK_TREE_MODEL (model);
+	gtk_list_store_set_column_types (GTK_LIST_STORE (model),
+					 PLACES_SIDEBAR_COLUMN_COUNT,
+					 model_types);
+
+	return GTK_LIST_STORE (model);
 }
