@@ -1000,6 +1000,7 @@ nautilus_window_pane_slot_close (NautilusWindowPane *pane,
 
 				DEBUG ("Calling set_active_pane, new slot %p", new_pane->active_slot);
 				nautilus_window_set_active_pane (window, new_pane);
+				nautilus_window_update_show_hide_menu_items (window);
 			} else {
 				DEBUG ("Last slot removed from the last pane, close the window");
 				nautilus_window_close (window);
@@ -1066,8 +1067,6 @@ nautilus_window_pane_close_slot (NautilusWindowPane *pane,
 
 	gtk_notebook_set_show_tabs (notebook,
 				    gtk_notebook_get_n_pages (notebook) > 1);
-
-	slot->pane = NULL;
 	pane->slots = g_list_remove (pane->slots, slot);
 }
 
